@@ -151,7 +151,7 @@ class KubeModel(ABC):
         
         self.logger.debug('saving file to host')
 
-        with open('/output/test.pkl', 'wb') as f:
+        with open('/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
             self.logger.debug('saving file, epoch: {self.epoch}')
             pickle.dump('test', f)
             self.logger.debug('file saved')
@@ -165,10 +165,10 @@ class KubeModel(ABC):
         
         self.logger.debug('loading file to host')
 
-        with open('/output/test.pkl', 'wb') as f:
+        with open('/output/{job_id}:test:{func_id}.pkl', 'wb') as f:
             self.logger.debug('loading file, epoch: {self.epoch}')
             state = pickle.load(f)
-            self.logger.debug('file loaded')
+            self.logger.debug('file loaded, value: {state}')
             print('file loaded')    
 
     def _save_optimizer_redis(self):
@@ -183,7 +183,7 @@ class KubeModel(ABC):
         weight_key = f'{job_id}:optimizer:{func_id}' 
         pickled_val  = pickle.dumps(self.optimizer.state_dict())
 
-        self.logger.debug(f"Optimizer value {pickled_val}")
+        self.logger.debug(f"Saving optimizer value: {pickled_val}")
 
         self._redis_client.set(weight_key, pickled_val)
 
@@ -325,6 +325,8 @@ class KubeModel(ABC):
         self.__load_model()
         self._load_optimizer_redis()
         self._load_redis_test()
+        self._load_file_test()
+
         #self._load_optimizer_state()
 
         #self._reset_optimizer_state()
@@ -337,6 +339,7 @@ class KubeModel(ABC):
         self.__save_model()
         self._save_optimizer_redis()
         self._save_redis_test()
+        self._save_file_test()
         #self._save_optimizer_state()
 
     def _batch_to_device(self, batch: Union[torch.Tensor, Iterable[torch.Tensor]]):
